# file_gcd

Toy package to calculate GCD from file input.

## standalone inputs and outputs

Call the program with `-h` to get program call arguments. The program can consume an input filepath and output filepath. From lines in the input file, where PROPERTY starts with `000`, the GCD of the columns NUM1, NUM2, ... will be calculated, row by row. The output is printed into stdout if no output filename is provided.

## python API

The package also provides a python API, use the source to figure out how.
